@@ -17,6 +17,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <time.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -330,7 +332,7 @@ void
 stack_shuffle(Stack *s)
 {
   int n, c, t;
-  int randomized = 0;
+  static int randomized = 0;
   if (! randomized)
   {
     srand(time(0));
