@@ -16,6 +16,7 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 #include <math.h>
@@ -377,6 +378,19 @@ xwin_nextevent (XWin_Event *ev)
   char c;
   static int click_button;
   static int last_resize_w=-1, last_resize_h=-1;
+  static int need_expose = 0;
+  static int window_is_mapped = 0;
+
+  if (need_expose && window_is_mapped)
+    {
+      ev->type = ev_expose;
+      ev->x = 0;
+      ev->y = 0;
+      ev->w = last_resize_w;
+      ev->h = last_resize_h;
+      need_expose = 0;
+      return ev_expose;
+    }
 
   while (1)
   {
@@ -397,6 +411,7 @@ xwin_nextevent (XWin_Event *ev)
 	  break;
 	last_resize_w = ev->w;
 	last_resize_h = ev->h;
+	need_expose = 1;
 	return ev_resize;
 	
       case Expose:
@@ -407,6 +422,8 @@ xwin_nextevent (XWin_Event *ev)
 	ev->y = event.xexpose.y;
 	ev->w = event.xexpose.width;
 	ev->h = event.xexpose.height;
+	window_is_mapped = 1;
+	need_expose = 0;
 	return ev_expose;
 
       case ButtonPress:
